@@ -207,10 +207,6 @@ _ostree_raw_file_to_archive_stream (GInputStream       *input,
                                     GCancellable       *cancellable,
                                     GError            **error);
 
-#ifndef OSTREE_ENABLE_EXPERIMENTAL_API
-gboolean ostree_validate_collection_id (const char *collection_id, GError **error);
-#endif /* !OSTREE_ENABLE_EXPERIMENTAL_API */
-
 gboolean
 _ostree_compare_timestamps (const char   *current_rev,
                             guint64       current_ts,
@@ -218,28 +214,4 @@ _ostree_compare_timestamps (const char   *current_rev,
                             guint64       new_ts,
                             GError      **error);
 
-#if (defined(OSTREE_COMPILATION) || GLIB_CHECK_VERSION(2, 44, 0)) && !defined(OSTREE_ENABLE_EXPERIMENTAL_API)
-#include <libglnx.h>
-#include "ostree-ref.h"
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeCollectionRef, ostree_collection_ref_free)
-G_DEFINE_AUTO_CLEANUP_FREE_FUNC (OstreeCollectionRefv, ostree_collection_ref_freev, NULL)
-
-#include "ostree-repo-finder.h"
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeRepoFinder, g_object_unref)
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeRepoFinderResult, ostree_repo_finder_result_free)
-G_DEFINE_AUTO_CLEANUP_FREE_FUNC (OstreeRepoFinderResultv, ostree_repo_finder_result_freev, NULL)
-
-#include "ostree-repo-finder-avahi.h"
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeRepoFinderAvahi, g_object_unref)
-
-#include "ostree-repo-finder-config.h"
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeRepoFinderConfig, g_object_unref)
-
-#include "ostree-repo-finder-mount.h"
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeRepoFinderMount, g_object_unref)
-
-#include "ostree-repo-finder-override.h"
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeRepoFinderOverride, g_object_unref)
-#endif
-
 G_END_DECLS
