@@ -151,6 +151,8 @@ struct OstreeRepo {
   uid_t target_owner_uid; /* Ensure files are chowned to this uid/gid */
   gid_t target_owner_gid;
   guint min_free_space_percent; /* See the min-free-space-percent config option */
+  guint64 min_free_space_mb; /* See the min-free-space-size config option */
+  gboolean cleanup_stagedir;
 
   guint test_error_flags; /* OstreeRepoTestErrorFlags */
 
@@ -435,56 +437,29 @@ _ostree_repo_get_remote_inherited (OstreeRepo  *self,
                                    const char  *name,
                                    GError     **error);
 
-#ifndef OSTREE_ENABLE_EXPERIMENTAL_API
-
-/* All the locking APIs below are duplicated in ostree-repo.h. Remove the ones
- * here once it's no longer experimental.
+/* Locking APIs are currently private.
+ * See https://github.com/ostreedev/ostree/pull/1555
  */
-
 typedef enum {
   OSTREE_REPO_LOCK_SHARED,
   OSTREE_REPO_LOCK_EXCLUSIVE
 } OstreeRepoLockType;
 
-gboolean      ostree_repo_lock_push (OstreeRepo          *self,
+gboolean      _ostree_repo_lock_push (OstreeRepo          *self,
                                      OstreeRepoLockType   lock_type,
                                      GCancellable        *cancellable,
                                      GError             **error);
-gboolean      ostree_repo_lock_pop (OstreeRepo    *self,
-                                    GCancellable  *cancellable,
-                                    GError       **error);
+gboolean      _ostree_repo_lock_pop (OstreeRepo    *self,
+                                     GCancellable  *cancellable,
+                                     GError       **error);
 
 typedef OstreeRepo OstreeRepoAutoLock;
 
-OstreeRepoAutoLock * ostree_repo_auto_lock_push (OstreeRepo          *self,
-                                                 OstreeRepoLockType   lock_type,
-                                                 GCancellable        *cancellable,
-                                                 GError             **error);
-void          ostree_repo_auto_lock_cleanup (OstreeRepoAutoLock *lock);
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeRepoAutoLock, ostree_repo_auto_lock_cleanup)
-
-const gchar * ostree_repo_get_collection_id (OstreeRepo   *self);
-gboolean      ostree_repo_set_collection_id (OstreeRepo   *self,
-                                             const gchar  *collection_id,
-                                             GError      **error);
-
-gboolean      ostree_repo_list_collection_refs (OstreeRepo                  *self,
-                                                const char                  *match_collection_id,
-                                                GHashTable                 **out_all_refs,
-                                                OstreeRepoListRefsExtFlags   flags,
-                                                GCancellable                *cancellable,
-                                                GError                     **error);
-
-void          ostree_repo_transaction_set_collection_ref (OstreeRepo                *self,
-                                                          const OstreeCollectionRef *ref,
-                                                          const char                *checksum);
-
-gboolean      ostree_repo_set_collection_ref_immediate (OstreeRepo                 *self,
-                                                        const OstreeCollectionRef  *ref,
-                                                        const char                 *checksum,
-                                                        GCancellable               *cancellable,
-                                                        GError                    **error);
-
-#endif  /* !OSTREE_ENABLE_EXPERIMENTAL_API */
+OstreeRepoAutoLock * _ostree_repo_auto_lock_push (OstreeRepo          *self,
+                                                  OstreeRepoLockType   lock_type,
+                                                  GCancellable        *cancellable,
+                                                  GError             **error);
+void          _ostree_repo_auto_lock_cleanup (OstreeRepoAutoLock *lock);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (OstreeRepoAutoLock, _ostree_repo_auto_lock_cleanup)
 
 G_END_DECLS
