@@ -245,7 +245,28 @@ resolve_refspec (OstreeRepo     *self,
     {
       ret_rev = g_strdup (ref);
     }
-  else if (remote != NULL)
+  else if (self->in_transaction)
+    {
+      const char *refspec;
+
+      if (remote != NULL)
+        refspec = glnx_strjoina (remote, ":", ref);
+      else
+        refspec = ref;
+
+      g_mutex_lock (&self->txn_lock);
+      if (self->txn.refs)
+        ret_rev = g_strdup (g_hash_table_lookup (self->txn.refs, refspec));
+      g_mutex_unlock (&self->txn_lock);
+    }
+
+  if (ret_rev != NULL)
+    {
+      ot_transfer_out_value (out_rev, &ret_rev);
+      return TRUE;
+    }
+
+  if (remote != NULL)
     {
       const char *remote_ref = glnx_strjoina ("refs/remotes/", remote, "/", ref);
 
@@ -470,7 +491,6 @@ ostree_repo_resolve_rev_ext (OstreeRepo                    *self,
   return _ostree_repo_resolve_rev_internal (self, refspec, allow_noent, FALSE, out_rev, error);
 }
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
 /**
  * ostree_repo_resolve_collection_ref:
  * @self: an #OstreeRepo
@@ -494,7 +514,7 @@ ostree_repo_resolve_rev_ext (OstreeRepo                    *self,
  * There are currently no @flags which affect the behaviour of this function.
  *
  * Returns: %TRUE on success, %FALSE on failure
- * Since: 2017.12
+ * Since: 2018.6
  */
 gboolean
 ostree_repo_resolve_collection_ref (OstreeRepo                    *self,
@@ -531,7 +551,6 @@ ostree_repo_resolve_collection_ref (OstreeRepo                    *self,
     *out_rev = g_strdup (ret_contents);
   return TRUE;
 }
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
 
 static gboolean
 enumerate_refs_recurse (OstreeRepo    *repo,
@@ -876,7 +895,6 @@ ostree_repo_remote_list_refs (OstreeRepo       *self,
   return TRUE;
 }
 
-#ifdef OSTREE_ENABLE_EXPERIMENTAL_API
 static gboolean
 remote_list_collection_refs_process_refs (OstreeRepo   *self,
                                           const gchar  *remote_name,
@@ -934,7 +952,7 @@ remote_list_collection_refs_process_refs (OstreeRepo   *self,
  * Any refs for other collections stored in the repository will also be returned.
  * No filtering is performed.
  *
- * Since: 2017.10
+ * Since: 2018.6
  */
 gboolean
 ostree_repo_remote_list_collection_refs (OstreeRepo    *self,
@@ -995,7 +1013,6 @@ ostree_repo_remote_list_collection_refs (OstreeRepo    *self,
   ot_transfer_out_value (out_all_refs, &ret_all_refs);
   return TRUE;
 }
-#endif  /* OSTREE_ENABLE_EXPERIMENTAL_API */
 
 static char *
 relative_symlink_to (const char *relpath,
@@ -1206,7 +1223,7 @@ _ostree_repo_update_collection_refs (OstreeRepo        *self,
  * %OSTREE_REPO_LIST_REFS_EXT_EXCLUDE_REMOTES in @flags.
  *
  * Returns: %TRUE on success, %FALSE otherwise
- * Since: 2017.8
+ * Since: 2018.6
  */
 gboolean
 ostree_repo_list_collection_refs (OstreeRepo                 *self,
