@@ -1,6 +1,8 @@
 /*
  * Copyright (C) 2013,2014 Colin Walters <walters@verbum.org>
  *
+ * SPDX-License-Identifier: LGPL-2.0+
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -55,11 +57,9 @@ typedef struct {
   GError        **async_error;
 
   OstreeObjectType output_objtype;
-  GLnxTmpfile      tmpf;
   guint64          content_size;
-  GOutputStream   *content_out;
-  GChecksum       *content_checksum;
   char             checksum[OSTREE_SHA256_STRING_LEN+1];
+  OstreeRepoBareContent content_out;
   char             *read_source_object;
   int               read_source_fd;
   gboolean        have_obj;
@@ -229,6 +229,9 @@ _ostree_static_delta_part_execute (OstreeRepo      *repo,
       state->oplen--;
       state->opdata++;
 
+      if (g_cancellable_set_error_if_cancelled (cancellable, error))
+        goto out;
+
       switch (opcode)
         {
         case OSTREE_STATIC_DELTA_OP_OPEN_SPLICE_AND_CLOSE:
@@ -275,9 +278,7 @@ _ostree_static_delta_part_execute (OstreeRepo      *repo,
 
   ret = TRUE;
  out:
-  glnx_tmpfile_clear (&state->tmpf);
-  g_clear_object (&state->content_out);
-  g_clear_pointer (&state->content_checksum, g_checksum_free);
+  _ostree_repo_bare_content_cleanup (&state->content_out);
   return ret;
 }
 
@@ -375,29 +376,6 @@ validate_ofs (StaticDeltaExecutionState  *state,
   return TRUE;
 }
 
-static gboolean
-content_out_write (OstreeRepo                 *repo,
-                   StaticDeltaExecutionState  *state,
-                   const guint8*               buf,
-                   gsize                       len,
-                   GCancellable               *cancellable,
-                   GError                    **error)
-{
-  gsize bytes_written;
-
-  if (state->content_checksum)
-    g_checksum_update (state->content_checksum, buf, len);
-
-  /* Ignore bytes_written since we discard partial content */
-  if (!g_output_stream_write_all (state->content_out,
-                                  buf, len,
-                                  &bytes_written,
-                                  cancellable, error))
-    return FALSE;
-
-  return TRUE;
-}
-
 static gboolean
 do_content_open_generic (OstreeRepo                 *repo,
                          StaticDeltaExecutionState  *state,
@@ -482,37 +460,15 @@ dispatch_bspatch (OstreeRepo                 *repo,
                    &stream) < 0)
         return FALSE;
 
-      if (!content_out_write (repo, state, buf, state->content_size,
-                              cancellable, error))
+      if (!_ostree_repo_bare_content_write (repo, &state->content_out,
+                                            buf, state->content_size,
+                                            cancellable, error))
         return FALSE;
     }
 
   return TRUE;
 }
 
-/* Before, we had a distinction between "trusted" and "untrusted" deltas
- * which we've decided wasn't a good idea.  Now, we always checksum the content.
- * Compare with what ostree_checksum_file_from_input() is doing too.
- */
-static gboolean
-handle_untrusted_content_checksum (OstreeRepo                 *repo,
-                                   StaticDeltaExecutionState  *state,
-                                   GCancellable               *cancellable,
-                                   GError                    **error)
-{
-  g_autoptr(GFileInfo) finfo = _ostree_mode_uidgid_to_gfileinfo (state->mode, state->uid, state->gid);
-  g_autoptr(GVariant) header = _ostree_file_header_new (finfo, state->xattrs);
-
-  state->content_checksum = g_checksum_new (G_CHECKSUM_SHA256);
-
-  gsize bytes_written;
-  if (!_ostree_write_variant_with_size (NULL, header, 0, &bytes_written, state->content_checksum,
-                                        cancellable, error))
-    return FALSE;
-
-  return TRUE;
-}
-
 static gboolean
 dispatch_open_splice_and_close (OstreeRepo                 *repo,
                                 StaticDeltaExecutionState  *state,
@@ -543,8 +499,13 @@ dispatch_open_splice_and_close (OstreeRepo                 *repo,
           goto out;
         }
 
-      metadata = g_variant_new_from_data (ostree_metadata_variant_type (state->output_objtype),
-                                          state->payload_data + offset, length, TRUE, NULL, NULL);
+      /* Unfortunately we need a copy because GVariant wants pointer-alignment
+       * and we didn't guarantee that in static deltas. We can do so in the
+       * future.
+       */
+      g_autoptr(GBytes) metadata_copy = g_bytes_new (state->payload_data + offset, length);
+      metadata = g_variant_new_from_bytes (ostree_metadata_variant_type (state->output_objtype),
+                                           metadata_copy, FALSE);
 
       {
         g_autofree guchar *actual_csum = NULL;
@@ -582,26 +543,26 @@ dispatch_open_splice_and_close (OstreeRepo                 *repo,
 
       /* Fast path for regular files to bare repositories */
       if (S_ISREG (state->mode) &&
-          (repo->mode == OSTREE_REPO_MODE_BARE ||
-           repo->mode == OSTREE_REPO_MODE_BARE_USER))
+          _ostree_repo_mode_is_bare (repo->mode))
         {
-          if (!_ostree_repo_open_content_bare (repo, state->checksum,
-                                               state->content_size,
-                                               &state->tmpf,
-                                               &state->have_obj,
-                                               cancellable, error))
+          if (!ostree_repo_has_object (repo, OSTREE_OBJECT_TYPE_FILE, state->checksum,
+                                       &state->have_obj, cancellable, error))
             goto out;
 
           if (!state->have_obj)
             {
-              state->content_out = g_unix_output_stream_new (state->tmpf.fd, FALSE);
-              if (!handle_untrusted_content_checksum (repo, state, cancellable, error))
+              if (!_ostree_repo_bare_content_open (repo, state->checksum,
+                                                   state->content_size,
+                                                   state->uid, state->gid, state->mode,
+                                                   state->xattrs,
+                                                   &state->content_out,
+                                                   cancellable, error))
                 goto out;
 
-              if (!content_out_write (repo, state,
-                                      state->payload_data + content_offset,
-                                      state->content_size,
-                                      cancellable, error))
+              if (!_ostree_repo_bare_content_write (repo, &state->content_out,
+                                                    state->payload_data + content_offset,
+                                                    state->content_size,
+                                                    cancellable, error))
                 goto out;
             }
         }
@@ -684,17 +645,20 @@ dispatch_open (OstreeRepo                 *repo,
   if (state->stats_only)
     return TRUE; /* Early return */
 
-  if (!_ostree_repo_open_content_bare (repo, state->checksum,
-                                       state->content_size,
-                                       &state->tmpf,
-                                       &state->have_obj,
-                                       cancellable, error))
+  if (!ostree_repo_has_object (repo, OSTREE_OBJECT_TYPE_FILE, state->checksum,
+                               &state->have_obj, cancellable, error))
     return FALSE;
-  if (!state->have_obj)
-    state->content_out = g_unix_output_stream_new (state->tmpf.fd, FALSE);
 
-  if (!handle_untrusted_content_checksum (repo, state, cancellable, error))
-    return FALSE;
+  if (!state->have_obj)
+    {
+      if (!_ostree_repo_bare_content_open (repo, state->checksum,
+                                           state->content_size,
+                                           state->uid, state->gid, state->mode,
+                                           state->xattrs,
+                                           &state->content_out,
+                                           cancellable, error))
+        return FALSE;
+    }
 
   return TRUE;
 }
@@ -705,7 +669,7 @@ dispatch_write (OstreeRepo                 *repo,
                GCancellable               *cancellable,
                GError                    **error)
 {
-  GLNX_AUTO_PREFIX_ERROR("opcode open-splice-and-close", error);
+  GLNX_AUTO_PREFIX_ERROR("opcode write", error);
   guint64 content_size;
   guint64 content_offset;
 
@@ -721,26 +685,26 @@ dispatch_write (OstreeRepo                 *repo,
     {
       if (state->read_source_fd != -1)
         {
-          if (lseek (state->read_source_fd, content_offset, SEEK_SET) == -1)
-            return glnx_throw_errno_prefix (error, "lseek");
           while (content_size > 0)
             {
               char buf[4096];
               gssize bytes_read;
 
               do
-                bytes_read = read (state->read_source_fd, buf, MIN(sizeof(buf), content_size));
+                bytes_read = pread (state->read_source_fd, buf, MIN(sizeof(buf), content_size), content_offset);
               while (G_UNLIKELY (bytes_read == -1 && errno == EINTR));
               if (bytes_read == -1)
                 return glnx_throw_errno_prefix (error, "read");
               if (G_UNLIKELY (bytes_read == 0))
                 return glnx_throw (error, "Unexpected EOF reading object %s", state->read_source_object);
 
-              if (!content_out_write (repo, state, (guint8*)buf, bytes_read,
-                                      cancellable, error))
+              if (!_ostree_repo_bare_content_write (repo, &state->content_out,
+                                                    (guint8*)buf, bytes_read,
+                                                    cancellable, error))
                 return FALSE;
 
               content_size -= bytes_read;
+              content_offset += bytes_read;
             }
         }
       else
@@ -748,8 +712,9 @@ dispatch_write (OstreeRepo                 *repo,
           if (!validate_ofs (state, content_offset, content_size, error))
             return FALSE;
 
-          if (!content_out_write (repo, state, state->payload_data + content_offset, content_size,
-                                  cancellable, error))
+          if (!_ostree_repo_bare_content_write (repo, &state->content_out,
+                                                state->payload_data + content_offset, content_size,
+                                                cancellable, error))
             return FALSE;
         }
     }
@@ -766,11 +731,7 @@ dispatch_set_read_source (OstreeRepo                 *repo,
   GLNX_AUTO_PREFIX_ERROR("opcode set-read-source", error);
   guint64 source_offset;
 
-  if (state->read_source_fd != -1)
-    {
-      (void) close (state->read_source_fd);
-      state->read_source_fd = -1;
-    }
+  glnx_close_fd (&state->read_source_fd);
 
   if (!read_varuint64 (state, &source_offset, error))
     return FALSE;
@@ -803,12 +764,7 @@ dispatch_unset_read_source (OstreeRepo                 *repo,
   if (state->stats_only)
     return TRUE; /* Early return */
 
-  if (state->read_source_fd != -1)
-    {
-      (void) close (state->read_source_fd);
-      state->read_source_fd = -1;
-    }
-
+  glnx_close_fd (&state->read_source_fd);
   g_clear_pointer (&state->read_source_object, g_free);
 
   return TRUE;
@@ -820,35 +776,24 @@ dispatch_close (OstreeRepo                 *repo,
                 GCancellable               *cancellable,
                 GError                    **error)
 {
-  GLNX_AUTO_PREFIX_ERROR("opcode open-splice-and-close", error);
+  GLNX_AUTO_PREFIX_ERROR("opcode close", error);
 
-  if (state->content_out)
+  if (state->content_out.initialized)
     {
-      if (!g_output_stream_flush (state->content_out, cancellable, error))
+      char actual_checksum[OSTREE_SHA256_STRING_LEN+1];
+      if (!_ostree_repo_bare_content_commit (repo, &state->content_out, actual_checksum,
+                                             sizeof (actual_checksum),
+                                             cancellable, error))
         return FALSE;
 
-      if (state->content_checksum)
-        {
-          const char *actual_checksum = g_checksum_get_string (state->content_checksum);
-
-          if (strcmp (actual_checksum, state->checksum) != 0)
-            return glnx_throw (error, "Corrupted object %s (actual checksum is %s)",
-                               state->checksum, actual_checksum);
-        }
-
-      if (!_ostree_repo_commit_trusted_content_bare (repo, state->checksum, &state->tmpf,
-                                                     state->uid, state->gid, state->mode,
-                                                     state->xattrs,
-                                                     cancellable, error))
-        return FALSE;
-      g_clear_object (&state->content_out);
+      g_assert_cmpstr (state->checksum, ==, actual_checksum);
     }
 
   if (!dispatch_unset_read_source (repo, state, cancellable, error))
     return FALSE;
 
   g_clear_pointer (&state->xattrs, g_variant_unref);
-  g_clear_pointer (&state->content_checksum, g_checksum_free);
+  _ostree_repo_bare_content_cleanup (&state->content_out);
 
   state->checksum_index++;
   state->output_target = NULL;
